@@ -4,27 +4,27 @@ Low-level autobuild functionality common to all modules.
 Any code that is potentially common to all autobuild sub-commands
 should live in this module. This module should never depend on any
 other autobuild module.
-
-Importing this module will also guarantee that certain dependencies
-are available, such as llbase
 """
 from __future__ import annotations
 
 import itertools
 import logging
+import multiprocessing
 import os
 import platform
 import pprint
 import subprocess
 import sys
+import tarfile
 import tempfile
 from collections import OrderedDict
 
+from pyzstd import CParameter, ZstdFile
+
 from autobuild.version import AUTOBUILD_VERSION_STRING
 
 logger = logging.getLogger(__name__)
 
-
 class AutobuildError(RuntimeError):
     pass
 
@@ -163,6 +163,7 @@ def establish_platform(specified_platform=None, addrsize=DEFAULT_ADDRSIZE):
     os.environ['AUTOBUILD_ADDRSIZE'] = str(addrsize) # for spawned commands
     os.environ['AUTOBUILD_PLATFORM'] = Platform # for spawned commands
     os.environ['AUTOBUILD_PLATFORM_OVERRIDE'] = Platform # for recursive invocations
+    os.environ['AUTOBUILD_CPU_COUNT'] = str(multiprocessing.cpu_count())
 
     logger.debug("Specified platform %s address-size %d: result %s" \
                  % (specified_platform, specified_addrsize, Platform))
@@ -338,6 +339,25 @@ def compute_md5(path):
     return hasher.hexdigest()
 
 
+def compute_blake2b(path):
+    """
+    Returns the blake2b sum for the given file.
+    """
+    import hashlib
+
+    try:
+        stream = open(path, 'rb')
+    except IOError as err:
+        raise AutobuildError("Can't compute blake2b for %s: %s" % (path, err))
+
+    try:
+        hasher = hashlib.blake2b(stream.read())
+    finally:
+        stream.close()
+
+    return hasher.hexdigest()
+
+
 def split_tarname(pathname):
     """
     Given a tarfile pathname of the form:
@@ -519,3 +539,26 @@ def has_cmd(name) -> bool:
     except OSError:
         return False
     return not p.returncode
+
+
+class ZstdTarFile(tarfile.TarFile):
+    def __init__(self, name, mode='r', *, level=4, zstd_dict=None, **kwargs):
+        zstdoption = None
+        if mode != 'r' and mode != 'rb':
+           zstdoption = {CParameter.compressionLevel : level,
+                         CParameter.nbWorkers : multiprocessing.cpu_count(),
+                         CParameter.checksumFlag : 1}
+        self.zstd_file = ZstdFile(name, mode,
+                                level_or_option=zstdoption,
+                                zstd_dict=zstd_dict)
+        try:
+            super().__init__(fileobj=self.zstd_file, mode=mode, **kwargs)
+        except:
+            self.zstd_file.close()
+            raise
+
+    def close(self):
+        try:
+            super().close()
+        finally:
+            self.zstd_file.close()
